skhubness.neighbors.RandomProjectionTree
========================================

.. currentmodule:: skhubness.neighbors

.. autoclass:: RandomProjectionTree

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~RandomProjectionTree.__init__
      ~RandomProjectionTree.fit
      ~RandomProjectionTree.get_params
      ~RandomProjectionTree.kneighbors
      ~RandomProjectionTree.set_params
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~RandomProjectionTree.valid_metrics
   
   